PyXMake Developer Guide: PyXMake.Build.Make.OS Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.OS Class Reference

Abstract base class for all system subclasses. More...

Inheritance diagram for PyXMake.Build.Make.OS:

## Public Member Functions
| __init__ (self, *args, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | SystemObjectKind = "Base"
| String identifier of current instance.

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Abstract base class for all system subclasses.

    Base class of all supported subsystems.

Inherited from built-in ABCMeta & object. Compatible with both Python 2.x and 3.x.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.OS.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Low-level initialization of parent class.

Reimplemented from PyXMake.Tools.Utility.AbstractBase.

Reimplemented in PyXMake.Build.Make.CCxx, PyXMake.Build.Make.Fortran, PyXMake.Build.Make.NT, PyXMake.Build.Make.POSIX, and PyXMake.Build.Make.Py2X.

Definition at line 108 of file Make.py.

## Member Data Documentation

## ◆ SystemObjectKind

str PyXMake.Build.Make.OS.SystemObjectKind = "Base"

String identifier of current instance.

Definition at line 110 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py